package be.iminds.ilabt.jfed.espec.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.List;

/**
 * DirSpec
 */
public class DirSpec {
    @Nonnull private final String path;
    @Nullable private final String content;
    @Nonnull private final String permissions;
    @Nullable private final List<String> nodes;

    public DirSpec(@Nonnull String path,
                   @Nullable String content,
                   @Nullable String permissions,
                   @Nullable List<String> nodes) {
        if (path.isEmpty())
            throw new IllegalArgumentException("Empty path is not valid");
        if (!path.startsWith("~") && !path.startsWith("/"))
            throw new IllegalArgumentException("path should start with either ~ or /");
        if (content != null && content.isEmpty())
            throw new IllegalArgumentException("Empty content is not valid (but null content is)");
        if (permissions != null && permissions.isEmpty())
            throw new IllegalArgumentException("Empty permissions is not valid (but null permissions is)");

        this.path = path;
        this.content = content;
        this.permissions = permissions == null ? "u=rwx" : permissions;
        this.nodes = nodes;
    }

    @Nonnull
    public String getPath() {
        return path;
    }

    @Nullable
    public String getContent() {
        return content;
    }

    public boolean isScriptContent() {
        if (content == null) return false;
        String m = content.toLowerCase().trim();
        return m.equals("script") || m.equals("scripts");
    }

    public boolean isUploadContent() {
        if (content == null) return false;
        String m = content.toLowerCase().trim();
        return m.equals("upload") || m.equals("uploads");
    }

    @Nonnull
    public String getPermissions() {
        return permissions;
    }

    @Nullable
    public List<String> getNodes() {
        return nodes;
    }
}
